@@ -5,7 +5,7 @@ use warnings;
 use Wx;
 use Carp;
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 # Define Perl 6 lexer
 use constant wxSCINTILLA_LEX_PERL6  => 102;
@@ -28,11 +28,11 @@ XSLoader::load 'Wx::Scintilla', $VERSION;
 no strict;
 
 package Wx::ScintillaTextCtrl;
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 @ISA = qw(Wx::Control);
 
 package Wx::ScintillaTextEvent;
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 @ISA = qw(Wx::CommandEvent);
 
 #Defeat the indexer by splitting the package declaration on two lines
@@ -49,32 +49,36 @@ use strict;
 	# Disable Wx::EVT_STC_* event warning redefinition
 	no warnings 'redefine';
 
-	sub EVT_STC_CHANGE($$$)            { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_CHANGE,            $_[2] ) }
-	sub EVT_STC_STYLENEEDED($$$)       { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_STYLENEEDED,       $_[2] ) }
-	sub EVT_STC_CHARADDED($$$)         { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_CHARADDED,         $_[2] ) }
-	sub EVT_STC_SAVEPOINTREACHED($$$)  { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_SAVEPOINTREACHED,  $_[2] ) }
-	sub EVT_STC_SAVEPOINTLEFT($$$)     { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_SAVEPOINTLEFT,     $_[2] ) }
-	sub EVT_STC_ROMODIFYATTEMPT($$$)   { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_ROMODIFYATTEMPT,   $_[2] ) }
-	sub EVT_STC_KEY($$$)               { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_KEY,               $_[2] ) }
-	sub EVT_STC_DOUBLECLICK($$$)       { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DOUBLECLICK,       $_[2] ) }
-	sub EVT_STC_UPDATEUI($$$)          { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_UPDATEUI,          $_[2] ) }
-	sub EVT_STC_MODIFIED($$$)          { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_MODIFIED,          $_[2] ) }
-	sub EVT_STC_MACRORECORD($$$)       { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_MACRORECORD,       $_[2] ) }
-	sub EVT_STC_MARGINCLICK($$$)       { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_MARGINCLICK,       $_[2] ) }
-	sub EVT_STC_NEEDSHOWN($$$)         { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_NEEDSHOWN,         $_[2] ) }
-	sub EVT_STC_POSCHANGED($$$)        { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_POSCHANGED,        $_[2] ) }
-	sub EVT_STC_PAINTED($$$)           { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_PAINTED,           $_[2] ) }
-	sub EVT_STC_USERLISTSELECTION($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_USERLISTSELECTION, $_[2] ) }
-	sub EVT_STC_URIDROPPED($$$)        { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_URIDROPPED,        $_[2] ) }
-	sub EVT_STC_DWELLSTART($$$)        { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DWELLSTART,        $_[2] ) }
-	sub EVT_STC_DWELLEND($$$)          { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DWELLEND,          $_[2] ) }
-	sub EVT_STC_START_DRAG($$$)        { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_START_DRAG,        $_[2] ) }
-	sub EVT_STC_DRAG_OVER($$$)         { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DRAG_OVER,         $_[2] ) }
-	sub EVT_STC_DO_DROP($$$)           { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DO_DROP,           $_[2] ) }
-	sub EVT_STC_ZOOM($$$)              { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_ZOOM,              $_[2] ) }
-	sub EVT_STC_HOTSPOT_CLICK($$$)     { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_HOTSPOT_CLICK,     $_[2] ) }
-	sub EVT_STC_HOTSPOT_DCLICK($$$)    { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_HOTSPOT_DCLICK,    $_[2] ) }
-	sub EVT_STC_CALLTIP_CLICK($$$)     { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_CALLTIP_CLICK,     $_[2] ) }
+	sub EVT_STC_CHANGE($$$)             { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_CHANGE,             $_[2] ) }
+	sub EVT_STC_STYLENEEDED($$$)        { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_STYLENEEDED,        $_[2] ) }
+	sub EVT_STC_CHARADDED($$$)          { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_CHARADDED,          $_[2] ) }
+	sub EVT_STC_SAVEPOINTREACHED($$$)   { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_SAVEPOINTREACHED,   $_[2] ) }
+	sub EVT_STC_SAVEPOINTLEFT($$$)      { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_SAVEPOINTLEFT,      $_[2] ) }
+	sub EVT_STC_ROMODIFYATTEMPT($$$)    { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_ROMODIFYATTEMPT,    $_[2] ) }
+	sub EVT_STC_KEY($$$)                { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_KEY,                $_[2] ) }
+	sub EVT_STC_DOUBLECLICK($$$)        { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DOUBLECLICK,        $_[2] ) }
+	sub EVT_STC_UPDATEUI($$$)           { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_UPDATEUI,           $_[2] ) }
+	sub EVT_STC_MODIFIED($$$)           { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_MODIFIED,           $_[2] ) }
+	sub EVT_STC_MACRORECORD($$$)        { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_MACRORECORD,        $_[2] ) }
+	sub EVT_STC_MARGINCLICK($$$)        { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_MARGINCLICK,        $_[2] ) }
+	sub EVT_STC_NEEDSHOWN($$$)          { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_NEEDSHOWN,          $_[2] ) }
+	sub EVT_STC_POSCHANGED($$$)         { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_POSCHANGED,         $_[2] ) }
+	sub EVT_STC_PAINTED($$$)            { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_PAINTED,            $_[2] ) }
+	sub EVT_STC_USERLISTSELECTION($$$)  { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_USERLISTSELECTION,  $_[2] ) }
+	sub EVT_STC_URIDROPPED($$$)         { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_URIDROPPED,         $_[2] ) }
+	sub EVT_STC_DWELLSTART($$$)         { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DWELLSTART,         $_[2] ) }
+	sub EVT_STC_DWELLEND($$$)           { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DWELLEND,           $_[2] ) }
+	sub EVT_STC_START_DRAG($$$)         { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_START_DRAG,         $_[2] ) }
+	sub EVT_STC_DRAG_OVER($$$)          { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DRAG_OVER,          $_[2] ) }
+	sub EVT_STC_DO_DROP($$$)            { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_DO_DROP,            $_[2] ) }
+	sub EVT_STC_ZOOM($$$)               { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_ZOOM,               $_[2] ) }
+	sub EVT_STC_HOTSPOT_CLICK($$$)      { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_HOTSPOT_CLICK,      $_[2] ) }
+	sub EVT_STC_HOTSPOT_DCLICK($$$)     { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_HOTSPOT_DCLICK,     $_[2] ) }
+	sub EVT_STC_CALLTIP_CLICK($$$)      { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_CALLTIP_CLICK,      $_[2] ) }
+	sub EVT_STC_INDICATOR_CLICK($$$)    { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_INDICATOR_CLICK,    $_[2] ) }
+	sub EVT_STC_INDICATOR_RELEASE($$$)  { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_INDICATOR_RELEASE,  $_[2] ) }
+	sub EVT_STC_AUTOCOMP_CANCELLED($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_AUTOCOMP_CANCELLED, $_[2] ) }
+	sub EVT_STC_AUTOCOMP_CHAR_DELETED($$$)   { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_STC_AUTOCOMP_CHAR_DELETED,   $_[2] ) }
 }
 
 1; # The end of Wx::Scintilla? :)
